@@ -8,11 +8,11 @@ functions. It also provides a GUI that can use pre-defined fitting methods.
 from __future__ import absolute_import, print_function
 
 __all__ = ['bootstrap', 'plot_fit',
-           'curve_fitting', 'kernel_smoothing',
+           'curve_fitting', 'nonparam_regression',
            'functions', 'residuals', 'CurveFitting']
 
-from . import functions
-from . import residuals
+from . import functions, residuals
+from . import bootstrap, plot_fit, curve_fitting, nonparam_regression
 from .curve_fitting import CurveFitting
 from path import path
 
