@@ -9,18 +9,13 @@ import numpy as np
 from numpy.random import randint
 from scipy import optimize
 from collections import namedtuple
-from . import kernel_smoothing
+from . import nonparam_regression
 from . import sharedmem
 import multiprocessing as mp
 from . import bootstrap_workers
 from .compat import irange, izip
 
 
-def adapt_curve_fit(fct, x, y, p0, args=(), **kwrds):
-    popt, pcov = optimize.curve_fit(fct, x, y, **kwrds)
-    return (popt, pcov, fct(popt, x, *args) - y)
-
-
 def percentile(array, p, axis=0):
     """
     Compute the percentiles of the values in array
@@ -61,7 +56,7 @@ def bootstrap_residuals(fct, xdata, ydata, repeats=3000, residuals=None,
 
     :type  add_residual: callable or None
     :param add_residual: Function that add a residual to a value. The call
-        ``add_residual(ydata, residual)`` should return the new ydata, with
+        ``add_residual(yopt, residual)`` should return the new ydata, with
         the residuals 'applied'. If None, it is considered the residuals should
         simply be added.
 
@@ -102,7 +97,8 @@ def bootstrap_residuals(fct, xdata, ydata, repeats=3000, residuals=None,
     shuffled_res = res[shuffle]
 
     if correct_bias:
-        kde = kernel_smoothing.LocalLinearKernel1D(xdata, res)
+        kde = nonparam_regression.NonParamRegression(xdata, res)
+        kde.fit()
         bias = kde(xdata)
         shuffled_res += bias
 
@@ -170,7 +166,7 @@ def getCIs(CI, *arrays):
 
     return CIs
 
-BootstrapResult = namedtuple('BootstrapResult', '''y_fit y_est y_eval CIs
+BootstrapResult = namedtuple('BootstrapResult', '''y_fit y_est eval_points y_eval CIs_val CIs
 shuffled_xs shuffled_ys full_results''')
 
 
@@ -248,6 +244,8 @@ def bootstrap(fit, xdata, ydata, CI, shuffle_method=bootstrap_residuals,
         confidence intervals and, if requested, the shuffled X, Y and the full
         estimated distributions.
     """
+    xdata = np.asarray(xdata)
+    ydata = np.asarray(ydata)
     y_fit = fit(xdata, ydata, *fit_args, **fit_kwrds)
     y_fit.fit()
 
@@ -326,7 +324,7 @@ def bootstrap(fit, xdata, ydata, CI, shuffle_method=bootstrap_residuals,
         result_array = result_array.copy()  # copy in local memory
         extra_arrays = [ea.copy for ea in extra_arrays]
 
-    return BootstrapResult(y_fit, y_fit(xdata), y_eval, CIs,
+    return BootstrapResult(y_fit, y_fit(xdata), eval_points, y_eval, tuple(CI), CIs,
                            shuffled_x, shuffled_y, result_array)
 
 
