@@ -5,13 +5,8 @@ Module implementing non-parametric regressions using kernel methods.
 """
 
 from __future__ import division, absolute_import, print_function
-from scipy import stats
-from scipy.linalg import sqrtm, solve
-import scipy
 import numpy as np
-from .compat import irange
 from . import npr_methods, kernels, kde_bandwidth
-from .utils import numpy_method_idx
 
 class NonParamRegression(object):
     r"""
@@ -39,6 +34,8 @@ class NonParamRegression(object):
         self._fitted_method = None
         self._n = None
         self._d = None
+        self._ytrans = None
+        self._fitted_ydata = None
 
         for kw in kwords:
             setattr(self, kw, kwords[kw])
@@ -160,6 +157,8 @@ class NonParamRegression(object):
         """
         Lower bound of the domain for each dimension
         """
+        if self._lower is None:
+            return -np.inf*np.ones(self.dim, dtype=float)
         return self._lower
 
     @lower.setter
@@ -178,6 +177,8 @@ class NonParamRegression(object):
         """
         Lower bound of the domain for each dimension
         """
+        if self._upper is None:
+            return np.inf*np.ones(self.dim, dtype=float)
         return self._upper
 
     @upper.setter
@@ -219,6 +220,33 @@ class NonParamRegression(object):
         self._ydata = yd
         self.need_fit()
 
+    @property
+    def fitted_ydata(self):
+        """
+        Data actually fitted. It may differ from ydata if ytrans is specified.
+        """
+        return self._fitted_ydata
+
+    @property
+    def ytrans(self):
+        """
+        Function used to transform the Y data before fitting.
+
+        This must be a callable that also has a ``inv`` attribute returning the inverse function.
+
+        :Note: The ``inv`` method must accept an ``out`` argument to store the output.
+        """
+        return self._ytrans
+
+    @ytrans.setter
+    def ytrans(self, tr):
+        assert hasattr(tr, '__call__') and hasattr(tr, 'inv'), "The transform must be a callable with an `inv` attribute"
+        self._ytrans = tr
+
+    @ytrans.deleter
+    def ytrans(self):
+        self._ytrans = None
+
     @property
     def method(self):
         """
@@ -273,18 +301,24 @@ class NonParamRegression(object):
         """
         D, N = self._xdata.shape
         assert self._ydata.shape[0] == N, "There must be as many points for X and Y"
+        if self.ytrans is not None:
+            self._fitted_ydata = self.ytrans(self.ydata)
+        else:
+            self._fitted_ydata = self.ydata
         self._kernel = self._create_kernel(D)
-        if self._lower is None:
-            self._lower = -np.inf * np.ones((D,), dtype=float)
-        if self._upper is None:
-            self._upper = np.inf * np.ones((D,), dtype=float)
         self._n = N
         self._d = D
+        lower = self.lower
+        upper = self.upper
+        assert len(lower) == D, "The 'lower' property must have one value per dimension of the domain."
+        assert len(upper) == D, "The 'upper' property must have one value per dimension of the domain."
         self._fitted_method = self._method.fit(self)
+        assert self.bandwidth.shape == (D, D), "The bandwidth should have a shape of ({0},{0}) (actual: {1})".format(D, self.bandwidth.shape)
+        assert self.covariance.shape == (D, D), "The covariance should have a shape of ({0},{0}) (actual: {1})".format(D, self.covariance.shape)
         self._fitted = True
 
     def evaluate(self, points, out=None):
-        if not self.fitter:
+        if not self.fitted:
             self.fit()
         points = np.asanyarray(points)
         real_shape = points.shape
@@ -299,6 +333,8 @@ class NonParamRegression(object):
             out.shape = (points.shape[-1],)
         self._fitted_method.evaluate(self, points, out)
         out.shape = real_shape[-1:]
+        if self.ytrans:
+            self.ytrans.inv(out, out=out)
         return out
 
     def __call__(self, points, out=None):
